
Istio on mugav tööriist jaotatud rakenduste ĂŒhendamiseks, kaitsmiseks ja jĂ€lgimiseks. Istios kasutatakse erinevaid tehnoloogiaid tarkvara skaleeritavaks kĂ€ivitamiseks ja haldamiseks, sealhulgas rakenduskoodi ja sĂ”ltuvuste pakendamiseks konteinerites ning Kubernetes - nende konteinerite haldamiseks. SeetĂ”ttu peate Istio kasutamiseks teadma, kuidas mitme teenusega rakendus nende tehnoloogiate pĂ”hjal toimib. ilma Istio. Kui need tööriistad ja mĂ”isted on teile juba tuttavad, jÀÀnud juhised vahele ja minge otse jaotisesse. vĂ”i laienduse installimine .
See on samm-sammuline juhend, kus vaatleme kogu protsessi lĂ€htekoodist kuni konteinerini GKE-s, et saaksite nende tehnoloogiate pĂ”hjal mugava ĂŒlevaate. Samuti nĂ€ete, kuidas Istio kasutab nende tehnoloogiate vĂ”imalusi. Eeldatakse, et te ei tea midagi konteineritest, Kubernetesest, teenuste vĂ”rgustikest vĂ”i Istio'st.
Ălesanded
Selles juhendis tĂ€idate jĂ€rgmisi ĂŒlesandeid:
- Lihtsa hello world rakenduse uurimine mitme teenusega.
- Rakenduse kÀitamine lÀhtekoodist.
- Rakenduse pakendamine konteineritesse.
- Kubernetes klastri loomine.
- Konteinerite juurutamine klastrisse.
Enne alustamist
JĂ€rgige juhiseid, et aktiveerida Kubernetes Engine API:
- Minge Google Cloud Platformi konsoolis.
- Looge vÔi valige projekt.
- Oodake, kuni API ja sellega seotud teenused aktiveeritakse. See vÔib vÔtta mitu minutit.
- Veenduge, et Google Cloud Platformi projekti jaoks on seadistatud arveldamine. .
Selles juhendis saate kasutada Cloud Shell'i, mis valmistab ette virtuaalmasina Debiani pÔhise Linuxiga vÔi Linuxi vÔi macOSi arvutiga.
Variant A: kasutades Cloud Shell'i
Cloud Shell'i kasutamise eelised:
- Python 2 ja Python 3 arenduskeskkonnad (sealhulgas virtualenv) on tÀiesti seadistatud.
- KÀsurea tööriistad gcloud, docker, git ja kubectl, mida me kasutame, on juba installitud.
- Teil on valikus mitu :
- , mis avatakse redigeerimise ikooniga Cloud Shell'i akna ĂŒlaosas.
- Emacs, Vim vÔi Nano, mis avanevad kÀsurealt Cloud Shell'is.
Cloud Shell'i kasutamiseks :
- Aktiveeri Cloud Shell
- KlĂ”psake nuppu (Aktiveerida Cloud Shell) GCP konsooli akna ĂŒlaosas. (Aktiveeri Cloud Shell) GCP-i konsooli akna ĂŒlaosas.
![]()
All pool a Cloud Shell session with a command line will open in a new window.

Option B: using command line tools locally
If you are working on a computer with Linux or macOS, you need to set up and install the following components:
Seadistage .
with the command line tool gcloud.
Installige kubectl â the command line tool for working with .
gcloud components install kubectlInstallige . You will use the command line tool docker, to build container images for the sample application.
Install the , to get the sample application from GitHub.
Download the code sample
Download the source code helloserver:
git clone https://github.com/GoogleCloudPlatform/istio-samplesChange to the code sample directory:
cd istio-samples/sample-apps/helloserver
Exploring the multi-service application
The sample application is written in Python and consists of two components that interact through :
- server: a simple server with a single endpoint GET, /, which outputs "hello world" to the console.
- loadgen: a script that sends traffic to server, with a configurable number of requests per second.

Running the application from the source code
To explore the sample application, run it in Cloud Shell or on your computer.
1) In the directory istio-samples/sample-apps/helloserver run server:
python3 server/server.pyKĂ€ivitamisel server the following will be displayed:
INFO:root:Starting server...2) Open another terminal window to send requests to server. If you are using Cloud Shell, click the add icon to open another session.
3) Send a request to server:
curl http://localhost:8080the server responds:
Tere maailm!4) From the directory where you downloaded the code sample, change to the directory that contains loadgen:
cd YOUR_WORKING_DIRECTORY/istio-samples/sample-apps/helloserver/loadgen5) Create the following environment variables:
export SERVER_ADDR=http://localhost:8080
export REQUESTS_PER_SECOND=56) Run virtualenv:
virtualenv --python python3 env7) Activate the virtual environment:
source env/bin/activate8) Install the requirements for loadgen:
pip3 install -r requirements.txt9) Run loadgen:
python3 loadgen.pyKĂ€ivitamisel loadgen outputs approximately the following message:
Starting loadgen: 2019-05-20 10:44:12.448415
5 request(s) complete to http://localhost:8080In another terminal window server outputs approximately the following messages to the console:
127.0.0.1 - - [21/Jun/2019 14:22:01] "GET / HTTP/1.1" 200 -
INFO:root:GET request,
Path: /VĂ”rgu seisukohalt töötab kogu rakendus ĂŒhel serveril (kohalik arvuti vĂ”i virtuaalne masin Cloud Shell). SeetĂ”ttu saab kasutada localhost, et saata pĂ€ringud server.
10) Peatamiseks loadgen ja server, sisestage Ctrl-c iga terminaliaknas.
11) Terminaliaknas loadgen deaktiveerige virtuaalne keskkond:
deactivateRakenduse pakkimine konteineritesse
Et kĂ€ivitada rakendus GKE-s, tuleb pakendada nĂ€idisrakendus â server ja loadgen â . Konteiner on viis rakenduse pakkimiseks, et isoleerida see keskkonnast.
Rakenduse pakendamiseks konteinerisse on vajalik Dockerfile. Dockerfile â see on tekstifail, kus mÀÀratakse rakenduse lĂ€htekoodi ja selle sĂ”ltuvuste koostamise kĂ€sklused PĂ€rast koostamist laadite pildi konteinerite registrisse, nĂ€iteks Docker Hub vĂ”i .
NÀites on juba olemas Dockerfile jaoks server ja loadgen koik vajalikud kÀsklused piltide koostamiseks. Allpool on Dockerfile jaoks server:
FROM python:3-slim as base
FROM base as builder
RUN apt-get -qq update
&& apt-get install -y --no-install-recommends
g++
&& rm -rf /var/lib/apt/lists/*
# LĂŒlita sisse vĂ€ljundlogimine
FROM base as final
ENV PYTHONUNBUFFERED=1
RUN apt-get -qq update
&& apt-get install -y --no-install-recommends
wget
WORKDIR /helloserver
# Noppige paketid ehitajalt
COPY --from=builder /usr/local/lib/python3.7/ /usr/local/lib/python3.7/
# Lisage rakendus
COPY . .
EXPOSE 8080
ENTRYPOINT [ "python", "server.py" ]- Meeskond FROM python:3-slim as base kÀskleb Dockeril kasutada viimast pildi kui baasi.
- Meeskond COPY. . kopeerib lĂ€htekoodid praegusesse töökausta (meie puhul ainult server.py) konteineri failisĂŒsteemi.
- ENTRYPOINT mÀÀrab kÀsu, mida kasutatakse konteineri kÀivitamiseks. Meie puhul on see kÀsk peaaegu sama, mis see, mida kasutasite lÀhtekoodist server.py kÀivitamiseks.
- Meeskond EXPOSE nÀitab, et server ootab andmeid porti 8080. See kÀsk ei See on midagi, mis sarnaneb dokumentatsiooniga, mis on vajalik uue porta avamiseks 8080 konteineri kÀivitamisel.
Rakenduse konteeneriseerimiseks ettevalmistamine
1) MÀÀrake jÀrgmised keskkonnamuutujad. Asendage PROJECT_ID oma GCP projekti ID-ga.
export PROJECT_ID="PROJECT_ID"export GCR_REPO="preparing-istio"Kasutades vÀÀrtusi PROJECT_ID ja GCR_REPO mÀrkite Docker pildi, kui koostate ja saadate selle eraldi Container Registry.
2) MÀÀrake vaikimisi GCP projekt kÀsurea tööriista jaoks gcloud.
gcloud config set project $PROJECT_ID3) MÀÀrake vaikimisi ala kÀsurea tööriista jaoks gcloud.
gcloud config set compute/zone us-central1-b4) Veenduge, et Container Registry teenus on GCP projektis lubatud.
gcloud services enable containerregistry.googleapis.comKonteineriseerimine server
Liikuge katalooge, kus asub nÀidis server:
cd YOUR_WORKING_DIRECTORY/istio-samples/sample-apps/helloserver/server/Koguge pilt jÀrgmise abil Dockerfile ja keskkonnamuutujate abil, mille mÀÀrasite varem:
docker build -t gcr.io/$PROJECT_ID/$GCR_REPO/helloserver:v0.0.1 .
Parameeter -t esindab Docker'i silti. See on pildi nimi, mida kasutate konteineri juurutamisel.
- Saatke pilt Container Registry'sse:
docker push gcr.io/$PROJECT_ID/$GCR_REPO/helloserver:v0.0.1
Konteineriseerimine loadgen
1) Liikuge katalooge, kus asub nÀidis loadgen:
cd ../loadgen2) Koguge pilt:
docker build -t gcr.io/$PROJECT_ID/$GCR_REPO/loadgen:v0.0.1 .3) Saatke pilt Container Registry'sse:
docker push gcr.io/$PROJECT_ID/$GCR_REPO/loadgen:v0.0.1Piltide loendi vaatamine
Vaadake piltide loendit hoidlas ja veenduge, et pildid on saadetud:
gcloud container images list --repository gcr.io/$PROJECT_ID/preparing-istioKĂ€sk tagastab just saadetud piltide nimed:
NAME
gcr.io/PROJECT_ID/preparing-istio/helloserver
gcr.io/PROJECT_ID/preparing-istio/loadgenGKE klastrite loomine.
Need konteinerid saaks toimida Cloud Shelli virtuaalses masinas vĂ”i teie arvutis kĂ€suga docker run. Kuid tootmisreĆŸiimis on vaja keskselt orkestreerida konteinereid. NĂ€iteks on vajalik sĂŒsteem, mis jĂ€lgib, et konteinerid töötaksid alati, ning on vajalik viis, kuidas suurendada ja kĂ€ivitada tĂ€iendavaid konteineri eksemplare, kui liiklus suureneb.
Konteinerirakenduste kĂ€ivitamiseks saab kasutada . GKE on konteinerite orkestreerimise platvorm, mis ĂŒhendab virtuaalsed masinad klastriks. Iga virtuaalne masin nimetatakse sĂ”lmeks. GKE klastrid pĂ”hinevad avatud lĂ€htekoodiga Kubernetes klastrihaldussĂŒsteemil. Kubernetes pakub mehhanisme klastriga suhtlemiseks.
GKE klastrite loomine:
1) Looge klaster:
gcloud container clusters create istioready
--cluster-version latest
--machine-type=n1-standard-2
--num-nodes 4Meeskond gcloud loob claster'i istioready GCP projektis ja vaikimisi piirkonnas, mille olete mÀÀranud. Istio kÀivitamiseks soovitame vÀhemalt 4 sÔlme ja virtuaalmasinat .
KÀsk loob klastrit mÔne minuti jooksul. Kui klaster on valmis, tagastab kÀsk sarnase .
2) MÀÀrake volitused kÀsurea tööriistale , et hallata klastrit:
gcloud container clusters get-credentials istioready3) NĂŒĂŒd saab suhelda Kubernetesega kubectl. NĂ€iteks jĂ€rgmise kĂ€suga saab teada sĂ”lmede oleku:
kubectl get nodesKÀsk tagastab sÔlmede loendi:
NIM STATUSE ROLLID VANUS VERSIOON
gke-istoready-default-pool-dbeb23dc-1vg0 Valmis 99s v1.13.6-gke.13
gke-istoready-default-pool-dbeb23dc-36z5 Valmis 100s v1.13.6-gke.13
gke-istoready-default-pool-dbeb23dc-fj7s Valmis 99s v1.13.6-gke.13
gke-istoready-default-pool-dbeb23dc-wbjw Valmis 99s v1.13.6-gke.13Kubernetesi pÔhikontseptsioonid
Diagrammil on kujutatud rakendus GKE-s:

Enne konteinerite kÀitamise alustamist GKE-s tutvuge Kubernetesi pÔhikontseptsioonidega. LÔpus on lingid, kui soovite rohkem teada.
- SÔlmed ja klastrid. GKE-s on sÔlm virtuaalmasin. Teistel Kubernetes platvormidel vÔib sÔlm olla arvuti vÔi virtuaalmasin. Klaster on sÔlmede kogum, mida saab pidada tervikuks ja kuhu te kÀrgitate konteineripÔhiseid rakendusi.
- Pod'id. Kuberneteses kĂ€ivitatakse konteinerid pod'ides. Pod Kuberneteses on jagamatu ĂŒksus. Pod sisaldab ĂŒhte vĂ”i mitut konteinerit. Te kĂ€rgitate konteinerid server ja loadgen erinevates pod'ides. Kui pod'is on mitu konteinerit (nĂ€iteks rakenduse server ja ), juhitakse konteinerid kui ĂŒhtset objekti ja nad jagavad pod'i ressursse.
- KÀivitamised. Kuberneteses on kÀitamine objekt, mis esindab identsete pod'ide kogumit. KÀitamine kÀivitab mitu pod'i koopiat, mis jaotatakse klastris olevatele sÔlmdele. KÀitamine asendab automaatselt need pod'id, mis ebaÔnnestuvad vÔi ei vasta.
- Kubernetesi teenus. Kui kĂ€ivitate rakenduse koodi GKE-s, muutub ĂŒhendus loadgen ja server. Kui olete kĂ€ivitanud teenused virtuaalses masinas Cloud Shellis vĂ”i arvutis, saatsite pĂ€ringud server aadressile localhost:8080. PĂ€rast kĂ€rgimist GKE-s kĂ€ivitatakse pod'id saadaval olevatel sĂ”lmedel. Vaikimisi ei saa te kuidagi hallata, millisel sĂ”lmel pod kĂ€ivitub, seega ei ole pĂŒsivaid IP-aadresse.
IP-aadressi saamiseks server, peate mÀÀratlema vĂ”rgu abstraktsiooni pod'ide kohal. See ongi . Kubernetesi teenus annab pĂŒsiva lĂ”pp-punkti pod'ide kogumile. On mitmeid . server kasutab LoadBalancer, mis pakuvad vĂ€list IP-aadressi, et ĂŒhenduda server klastrist vĂ€ljaspool.
Kuberneteses on samuti sisseehitatud DNS-sĂŒsteem, mis mÀÀrab DNS-nimed (nĂ€iteks helloserver.default.cluster.local) teenustele. Selle tĂ”ttu suhtlevad podâid klastris teiste podâidega pĂŒsiva aadressi kaudu. DNS-i nime ei saa klastrist vĂ€ljaspool kasutada, nĂ€iteks Cloud Shellis vĂ”i teie arvutis.
Kubernetesâi manifestid
Kui kÀivitasite rakenduse lÀhtekoodist, kasutasite imperatiivset kÀsku python3
server.py
Imperatiivsuse mÔiste hÔlmab tegusÔna: "tee seda".
Kubernetes kasutab . See tĂ€hendab, et me ei ĂŒtle Kubernetesâele, mida tĂ€pselt teha, vaid kirjeldame soovitud olekut. NĂ€iteks kĂ€ivitab Kubernetes ja peatab podâid vastavalt vajadusele, et tĂ”eline sĂŒsteemi seisund vastaks soovitule.
Soovitud oleku mÀÀrate manifestides vĂ”i failides . YAML-fail sisaldab spetsifikatsioonid ĂŒhe vĂ”i mitme Kubernetesâi objekti jaoks.
NĂ€ites sisaldub YAML-fail server ja loadgen. Iga YAML-fail mÀÀratleb ĆŸelŃ mĐ”ŃŃŃŃ ĐŸĐ»ĐžĐŸobedĐŒŃĐŸĐ±ĐșĐœĐ”Đ·Đ°ŃĐŸŃĐŸĐŒ â Ń ŃĐ”ŃĐČĐžŃа Kubernetesâist.
server.yaml
apiVersion: apps/v1
kind: Deployment
metadata:
name: helloserver
spec:
selector:
matchLabels:
app: helloserver
replicas: 1
template:
metadata:
labels:
app: helloserver
spec:
terminationGracePeriodSeconds: 5
restartPolicy: Always
containers:
- name: main
image: gcr.io/google-samples/istio/helloserver:v0.0.1
imagePullPolicy: Always- kind mÀÀrab objekti tĂŒĂŒbi.
- metadata.name mÀÀrab vÀljalaskmise nime.
- Esimene vÀli spec sisaldab soovitud oleku kirjeldust.
- spec.replicas mÀÀrab soovitud podâide arvu.
- Jaotis spec.template mÀÀratleb podâi mall. Podâide spetsifikatsioonis on vĂ€li image, kus mÀÀratakse konteinerifaili nimi, mille tuleb Container Registryâst vĂ€lja vĂ”tta.
Teenust mÀÀratletakse jÀrgmiselt:
apiVersion: v1
kind: Service
metadata:
name: hellosvc
spec:
type: LoadBalancer
selector:
app: helloserver
ports:
- name: http
port: 80
targetPort: 8080- LoadBalancer: kliendid saadavad pĂ€ringud koormusbalansi IP-aadressile, millel on pĂŒsiv IP-aadress ja mis on kergesti juurdepÀÀsetav klastrist vĂ€ljaspool.
- targetPort: nagu mĂ€letate, kĂ€sk EXPOSE 8080 ja Dockerfile ei pakkunud porte. Te mÀÀrate pordi 8080, et oleks vĂ”imalik suhelda konteineriga server klastrist vĂ€ljaspool. Meie puhul hellosvc.default.cluster.local:80 (lĂŒhinimi: hellosvc) vastab pordile 8080 podâi IP-aadress helloserver.
- port: see on pordinumber, kuhu teised teenused klastris saadavad pÀringud.
loadgen.yaml
KÀivitamisobjekt loadgen.yaml on server.yamlsarnane env. Erinevus seisneb selles, et kÀivitamisobjekt sisaldab jaotist loadgen . See mÀÀratleb keskkonnamuutujad, mis on vajalikud, ja mida te mÀÀrasite rakenduse kÀivitamisel lÀhtekoodist.
apiVersion: apps/v1
kind: Deployment
metadata:
name: loadgenerator
spec:
selector:
matchLabels:
app: loadgenerator
replicas: 1
template:
metadata:
labels:
app: loadgenerator
spec:
terminationGracePeriodSeconds: 5
restartPolicy: Always
containers:
- name: main
image: gcr.io/google-samples/istio/loadgen:v0.0.1
imagePullPolicy: Always
env:
- name: SERVER_ADDR
value: "http://hellosvc:80/"
- name: REQUESTS_PER_SECOND
value: "10"
resources:
requests:
cpu: 300m
memory: 256Mi
limits:
cpu: 500m
memory: 512MiĂks loadgen ei vĂ”ta sisenevaid pĂ€ringuid, vĂ€lja arvatud type mĂ€rgitud ClusterIP. See tĂŒĂŒp pakub pĂŒsivat IP-aadressi, mida saavad kasutada klastris olevad teenused, kuid see IP-aadress ei ole vĂ€listele klientidele saadaval.
apiVersion: v1
kind: Service
metadata:
name: loadgensvc
spec:
type: ClusterIP
selector:
app: loadgenerator
ports:
- name: http
port: 80
targetPort: 8080Konteinerite juurutamine GKE-s
1) Liikuge katalooge, kus asub nÀidis server:
cd YOUR_WORKING_DIRECTORY/istio-samples/sample-apps/helloserver/server/2) Avage server.yaml tekstiredaktoris.
3) Asendage nimi vÀlja image oma Docker-pildiga nimega.
image: gcr.io/PROJECT_ID/preparing-istio/helloserver:v0.0.1Asendage PROJECT_ID oma GCP projekti ID-ga.
4) Salvestage ja sulgege server.yaml.
5) Juurutage YAML-fail Kubernetesesse:
kubectl apply -f server.yamlPÀrast eduka kÀivitamise korral annab kÀsk jÀrgmise koodi:
deployment.apps/helloserver created
service/hellosvc created6) Minge kausta, kus asub loadgen:
cd ../loadgen7) Avage loadgen.yaml tekstiredaktoris.
8) Asendage nimi vÀlja image oma Docker-pildiga nimega.
image: gcr.io/PROJECT_ID/preparing-istio/loadgenv0.0.1Asendage PROJECT_ID oma GCP projekti ID-ga.
9) Salvestage ja sulgege loadgen.yaml, sulgege tekstiredaktor.
10) Juurutage YAML-fail Kubernetesesse:
kubectl apply -f loadgen.yamlPÀrast eduka kÀivitamise korral annab kÀsk jÀrgmise koodi:
deployment.apps/loadgenerator created
service/loadgensvc created11) Kontrollige pods'i staatust:
kubectl get podsKÀsk nÀitab staatust:
NAME READY STATUS RESTARTS AGE
helloserver-69b9576d96-mwtcj 1/1 Running 0 58s
loadgenerator-774dbc46fb-gpbrz 1/1 Running 0 57s12) TÔmmake rakenduse logisid podist loadgen. Asendage POD_ID eelnevalt saadud ID.
kubectl logs loadgenerator-POD_ID13) Hankige vÀlised IP-aadressid hellosvc:
kubectl get serviceKÀsk tagastab umbes jÀrgmise:
NAME TYPE CLUSTER-IP EXTERNAL-IP PORT(S) AGE
hellosvc LoadBalancer 10.81.15.158 192.0.2.1 80:31127/TCP 33m
kubernetes ClusterIP 10.81.0.1 443/TCP 93m
loadgensvc ClusterIP 10.81.15.155 80/TCP 4m52s14) Saada pÀring hellosvc: asendage EXTERNAL_IP vÀlise IP-aadressiga hellosvc.
curl http://EXTERNAL_IPTegeleme Istio'ga
Teil on juba rakendus, mis on juurutatud GKE-s. loadgen vÔib kasutada Kubernetes DNS-i (hellosvc:80), et saata pÀringuid server, ja saate saata pÀringuid server vÀlise IP-aadressiga. Kuigi Kubernetesel on palju vÔimalusi, puudub teavet teenuste kohta:
- Kuidas teenused omavahel suhtlevad? Millised on teenuste omavahelised suhted? Kuidas voolab liiklus teenuste vahel? Kas te olete teadlikud, et loadgen saab pĂ€ringud server, kuid kujutage ette, et te ei tea rakendusest midagi. Nendele kĂŒsimustele vastamiseks vaatame GKE-s kĂ€ivitatud podide loendit.
- MÔÔtmised. Kui kaua server vastab sissetulevale pÀringule? Kui palju pÀringuid sekundis serverisse jÔuab? Kas ta annab veateateid?
- Turvaandmed. Liiklus teenuste vahel loadgen ja server lÀbib lihtsalt HTTP vÔi ?
KĂ”igile nendele kĂŒsimustele vastab Istio. Selleks paigutab Istio igasse podi sidecar-proksi Proksi Envoy pĂŒĂŒdab kinni kogu sissetuleva ja vĂ€ljamineva liikluse rakenduse konteineritele. See tĂ€hendab, et server ja loadgen saadakse sidecar-proksi Envoy'i kaudu ja kogu liiklus loadgen aadressile server lĂ€bib proksi Envoy'i.
Proksi Envoy'de vahelised ĂŒhendused moodustavad teenuste vĂ”rgu. Teenuste vĂ”rgu arhitektuur annab Kubernetes'ile ĂŒlemise tasandi kontrolli.

Kuna proksi Envoy töötavad oma konteinerites, saab Istio paigaldada GKE klastrisse, peaaegu muutmata rakenduse koodi. Kuid te olete teinud mÔningaid ettevalmistusi rakenduse tegemiseks Istio haldamiseks:
- Teenused kÔigi konteinerite jaoks. Iga rakendamine server ja loadgen on seotud Kubernetes'e teenusega. Isegi loadgen, kuhu ei tule sissetulevaid pÀringuid, on teenus.
- Teenuste portidel peavad olema nimed. Kuigi GKE-s vÔib teenuste porte nimeta jÀtta, nÔuab Istio vastavalt tema protokollile. YAML-failis on port server kandideerib http, kuna server kasutab protokolli HTTP. Kui teenus kasutaks gRPC, siis nimetaksite porti grpc.
- Rakendusi mĂ€rgistatakse. SeetĂ”ttu saate kasutada Istio liikluse juhtimise funktsioone, nĂ€iteks jagada liiklust ĂŒhe teenuse versioonide vahel.
Istio installimine
Istio installimiseks on kaks meetodit. VĂ”ite vĂ”i klastrisse. Istio on GKE abil on lihtne hallata Istio paigaldamist ja uuendamist GKE klastro elutsĂŒkli raames. Kui vajate kĂ”ige uuemat Istio versiooni vĂ”i rohkem kontrolli Istio juhtpaneeli seadistuse ĂŒle, installige avatud lĂ€htekoodiga versioon, mitte Istio on GKE laiendus. Otsustamiseks lugege artiklit .
Valige variant, uurige vastavat juhendit ja jÀrgige juhiseid, et paigaldada Istio klastrisse. Kui soovite kasutada Istio just valminud rakendusega, nimeala SeejÀrel kÀivitame exec kÀsu ja ootame 5000 sekundit, et jÀtkata jÀlgimist:.
Puhastamine
Et vÀltida Google Cloud Platformi konto arveldamist nende ressursside eest, mida oled selles juhendis kasutanud, eemalda konteineriklaster pÀrast Istio installimist ja rakenduse nÀitega mÀngimist. Sellega eemaldatakse kÔik klastriga seotud ressursid, nÀiteks arvutieksemplarid, kettad ja vÔrguressursid.
Mis edasi?
Uuri jÀrgmisi tehnoloogiaid:
Uuri jÀrgmisi tööriistu:
Uuri Kubernetes'e kontseptsioone:
Allikas: habr.com
